@@ -1,4 +1,4 @@
-#![feature(const_generics)]
+#![feature(adt_const_params)]
 
 mod collection;
 mod error;
@@ -102,7 +102,7 @@ mod tests {
         let data = vec![
             0,0,0,0,0,0,0,0
         ];
-        let original = LTVNoBody::from_ltv_object(&data).unwrap();
+        LTVNoBody::from_ltv_object(&data).unwrap();
     }
 
 }
