@@ -1,4 +1,4 @@
-use std::{convert::{TryFrom, TryInto}, u128};
+use std::{convert::{TryInto}, u128};
 
 use crate::{
     error::{LTVError, LTVResult},
@@ -198,6 +198,8 @@ impl_numeric_ltvitem! {
     i16,
     u32,
     i32,
+    u64, 
+    i64,
     u128,
     i128
 }
